window.Gleam.initSearch([{"doc":"eventsourcing_postgres","title":"eventsourcing_postgres","content":"&lt;h1 align=&quot;center&quot;&gt;Eventsourcing Postgres&lt;/h1&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  ✨ &lt;strong&gt;Event Sourcing Library for Gleam with PostgreSQL&lt;/strong&gt; ✨\n&lt;/div&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  A Gleam library for building event-sourced systems using PostgreSQL as the event store.\n&lt;/div&gt;\n\n&lt;br /&gt;\n\n&lt;div align=&quot;center&quot;&gt;\n  &lt;a href=&quot;https://hex.pm/packages/eventsourcing_postgres&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/hexpm/v/eventsourcing_postgres&quot; alt=&quot;Available on Hex&quot; /&gt;\n  &lt;/a&gt;\n  &lt;a href=&quot;https://hexdocs.pm/eventsourcing_postgres&quot;&gt;\n    &lt;img src=&quot;https://img.shields.io/badge/hex-docs-ffaff3&quot; alt=&quot;Documentation&quot; /&gt;\n  &lt;/a&gt;\n&lt;/div&gt;\n\n---\n\n## Table of contents\n\n- [Introduction](#introduction)\n- [Features](#features)\n- [Concurrency Safety](#concurrency-safety)\n- [Philosophy](#philosophy)\n- [Installation](#installation)\n- [Support](#support)\n- [Contributing](#contributing)\n- [License](#license)\n\n## Introduction\n\n`eventsourcing_postgres` is a Gleam library designed to help developers build event-sourced systems using PostgreSQL. Event sourcing is a pattern where changes to the application&#39;s state are stored as a sequence of events.\n\n## Features\n\n- **Event Sourcing**: Build systems based on the event sourcing pattern.\n- **PostgreSQL Event Store**: Robust event store implementation using PostgreSQL.\n- **Command Handling**: Handle commands and produce events with robust error handling.\n- **Event Application**: Apply events to update aggregates.\n- **Snapshotting**: Optimize aggregate rebuilding with configurable snapshots.\n- **Type-safe Error Handling**: Comprehensive error types and Result-based API.\n- **Concurrency Safe**: Uses pessimistic concurrency to ensure safe concurrent access.\n\n## Concurrency Safety\n\n### What is Pessimistic Concurrency?\n\nPessimistic concurrency is a method of managing concurrent access to a resource by locking it when a transaction is being performed. This ensures that no other transaction can modify the resource until the lock is released.\n\n### Why is it Important?\n\nIn the context of event sourcing, multiple transactions could attempt to modify the same aggregate simultaneously. Without proper concurrency control, this could lead to inconsistencies in the stored events. Pessimistic concurrency ensures that only one transaction can modify an aggregate at any given time, preserving data integrity and consistency.\n\n## Philosophy\n\neventsourcing_postgres is designed to make building event-sourced systems easy and intuitive.\nIt encourages a clear separation between command handling and event application,\nmaking your code more maintainable and testable.\n\n## Installation\n\nAdd eventsourcing_postgres to your Gleam projects from the command line:\n\n``` sh\ngleam add eventsourcing_postgres@1\n```\n\n## Support\n\neventsourcing_postgres is built by Renatillas.\nContributions are very welcome!\nIf you&#39;ve spotted a bug, or would like to suggest a feature,\nplease open an issue or a pull request.\n\n## Contributing\n\nContributions are welcome! Please follow these steps:\n\n1. Fork the repository.\n2. Create a new branch (git checkout -b my-feature-branch).\n3. Make your changes and commit them (git commit -m &#39;Add new feature&#39;).\n4. Push to the branch (git push origin my-feature-branch).\n5. Open a pull request.\n6. Please ensure your code adheres to the project&#39;s coding standards and includes appropriate tests.\n\n## License\n\nThis project is licensed under the MIT License. See the LICENSE file for details.\n","url":"index.html"},{"doc":"eventsourcing_postgres","title":"create_event_table","content":"pub fn create_event_table(\n  postgres_store: PostgresStore(a, b, c, d),\n) -&gt; Result(Nil, EventSourcingError(d))\n\nSynonyms:\neventsourcing_postgres.create_event_table\neventsourcing_postgres create_event_table","url":"eventsourcing_postgres.html#create_event_table"},{"doc":"eventsourcing_postgres","title":"create_snapshot_table","content":"pub fn create_snapshot_table(\n  postgres_store: PostgresStore(a, b, c, d),\n) -&gt; Result(Nil, EventSourcingError(d))\n\nSynonyms:\neventsourcing_postgres.create_snapshot_table\neventsourcing_postgres create_snapshot_table","url":"eventsourcing_postgres.html#create_snapshot_table"},{"doc":"eventsourcing_postgres","title":"new","content":"pub fn new(\n  pgo_config pgo_config: Config,\n  event_encoder event_encoder: fn(a) -&gt; String,\n  event_decoder event_decoder: Decoder(a),\n  event_type event_type: String,\n  event_version event_version: String,\n  aggregate_type aggregate_type: String,\n  entity_encoder entity_encoder: fn(b) -&gt; String,\n  entity_decoder entity_decoder: Decoder(b),\n) -&gt; EventStore(PostgresStore(b, c, a, d), b, c, a, d, Connection)\n\nSynonyms:\neventsourcing_postgres.new\neventsourcing_postgres new","url":"eventsourcing_postgres.html#new"},{"doc":"eventsourcing_postgres","title":"eventsourcing_postgres","content":"","url":"eventsourcing_postgres.html"}]);